@@ -1,10 +1,10 @@
 use quote::quote;
 use syn::Result;
 
-use crate::{attr::Inflection, deps::Dependencies, DerivedTS};
+use crate::{attr::StructAttr, deps::Dependencies, DerivedTS};
 
-pub(crate) fn unit(name: &str, rename_all: &Option<Inflection>) -> Result<DerivedTS> {
-    if rename_all.is_some() {
+pub(crate) fn unit(attr: &StructAttr, name: &str) -> Result<DerivedTS> {
+    if attr.rename_all.is_some() {
         syn_err!("`rename_all` is not applicable to unit structs");
     }
 
@@ -14,5 +14,7 @@ pub(crate) fn unit(name: &str, rename_all: &Option<Inflection>) -> Result<Derive
         inline_flattened: None,
         name: name.to_owned(),
         dependencies: Dependencies::default(),
+        export: attr.export,
+        export_to: attr.export_to.clone(),
     })
 }
